@@ -17,6 +17,7 @@
  *)
 
 open Unix
+open Unix.LargeFile
 open Printf
 
 open Utils
@@ -219,7 +220,10 @@ let pacman_download_all_packages pkgs dir =
   let cmd =
     sprintf "
       umask 0000
-      for f in %s/*.pkg.tar.*; do tar -xf \"$f\" -C %s; done
+      for f in %s/*.pkg.tar.*; do
+        [[ $f == *.sig ]] && continue
+        tar -xf \"$f\" -C %s
+      done
     "
       (quote tdir) (quote dir) in
   if !settings.debug >= 2 then printf "%s" cmd;
